@@ -151,6 +151,7 @@ create_schema <- function(.con,database_name,schema_name){
 #' @keywords internal
 create_table_tbl <- function(.data,.con,database_name,schema_name,table_name,write_type="overwrite"){
 
+
     # Validate write_type
     write_type <- rlang::arg_match(write_type,values = c("overwrite","append"))
 
@@ -175,27 +176,23 @@ create_table_tbl <- function(.data,.con,database_name,schema_name,table_name,wri
       schema_name <- pwd(.con)[["current_schema"]]
       )
     }
-
-    database_name <- DBI::dbQuoteIdentifier(conn = .con,x = database_name)
-#
-    if(md_con_indicator){
-
-#         # Create and connect to the database
-        DBI::dbExecute(.con, glue::glue_sql("CREATE DATABASE IF NOT EXISTS {database_name}; USE {database_name};", .con = .con))
-
+    
+    # validate database exists 
+    
+    if(!validate_database_exists(.con=.con,database_name = database_name)){
+      
+      cli::cli_abort("Database {.val database_name} does not exists")
+      
     }
-
-    # # Create schema
-    Sys.sleep(1)
-
-    schema_name <- DBI::dbQuoteIdentifier(conn = .con,x=schema_name)
-
-    if(md_con_indicator){
-
-    DBI::dbExecute(.con, glue::glue_sql("CREATE SCHEMA IF NOT EXISTS {schema_name}; USE {schema_name};", .con = .con))
-
+    
+    # validate schemas exists 
+    
+    if(!validate_database_schema_exists(.con=.con,database_name = database_name,schema_name = schema_name)){
+      
+      cli::cli_abort("Schema {.vaal schema_name} does not exist in {.val database_name}")
+      
     }
-
+    
 
 
     # Add audit fields
@@ -209,7 +206,7 @@ create_table_tbl <- function(.data,.con,database_name,schema_name,table_name,wri
 
     # Use DBI::Id to ensure schema is used explicitly
 
-    table_id <- DBI::Id(table = table_name)
+    table_id <- DBI::Id(database_name=database_name,schema_name=schema_name,table = table_name)
 
     # Write table
     if (write_type == "overwrite") {
@@ -267,6 +264,7 @@ create_table_tbl <- function(.data,.con,database_name,schema_name,table_name,wri
 create_table_dbi <- function(.data,.con,database_name,schema_name,table_name,write_type="overwrite"){
 
 
+  
   # Validate write_type
   write_type <- rlang::arg_match(write_type,values = c("overwrite","append"))
 
@@ -287,18 +285,25 @@ create_table_dbi <- function(.data,.con,database_name,schema_name,table_name,wri
     )
 
   }
-
-  if(md_con_indicator){
-    # Create and connect to the database
-    DBI::dbExecute(.con, glue::glue_sql("CREATE DATABASE IF NOT EXISTS {`database_name`};USE {`database_name`};", .con = .con))
+  
+ 
+  # validate database exists 
+  
+  if(!validate_database_exists(.con=.con,database_name = database_name)){
+    
+    cli::cli_abort("Database {.val database_name} does not exists")
+    
+  }
+  
+  # validate schemas exists 
+  
+  if(!validate_database_schema_exists(.con=.con,database_name = database_name,schema_name = schema_name)){
+    
+    cli::cli_abort("Schema {.val schema_name} does not exist in {.val database_name}")
+    
   }
 
-  Sys.sleep(1)
-  # Create schema
-  if(md_con_indicator){
-  DBI::dbExecute(.con, glue::glue_sql("CREATE SCHEMA IF NOT EXISTS {`schema_name`}; USE {`schema_name`};", .con = .con))
-}
-
+  # assign time stamps for upload
   date_vec <- Sys.Date()
   time_vec <- format(Sys.time(), "%H:%M:%S  %Z",tz = Sys.timezone())
 
@@ -311,20 +316,20 @@ create_table_dbi <- function(.data,.con,database_name,schema_name,table_name,wri
     dbplyr::remote_query()
 
 
-  table_name_id <- DBI::dbQuoteIdentifier(.con,table_name)
+  table_id <- DBI::Id(database_name=database_name,schema_name=schema_name,table = table_name)
 
   # Write table
   if (write_type == "overwrite") {
 
-    DBI::dbExecute(.con, glue::glue_sql("DROP TABLE IF EXISTS {table_name_id};",.con = .con))
+    DBI::dbExecute(.con, glue::glue_sql("DROP TABLE IF EXISTS {dbQuoteIdentifier(.con,table_id)};",.con = .con))
 
-    Sys.sleep(1)
+    Sys.sleep(5)
 
-    DBI::dbExecute(.con,glue::glue_sql("CREATE TABLE IF NOT EXISTS {table_name_id} AS ",query_plan,.con = .con))
+    DBI::dbExecute(.con,glue::glue_sql("CREATE TABLE IF NOT EXISTS {dbQuoteIdentifier(.con,table_id)} AS ",query_plan,.con = .con))
 
   } else if (write_type == "append") {
 
-    DBI::dbExecute(.con,glue::glue_sql("INSERT INTO {table_name_id} ",query_plan,.con = .con))
+    DBI::dbExecute(.con,glue::glue_sql("INSERT INTO {dbQuoteIdentifier(.con,table_id)} ",query_plan,.con = .con))
 
   }
 
@@ -1134,11 +1139,147 @@ convert_table_to_sql_id <- function(x) {
 
 
 
+#' @title Check if a Database Exists
+#' @name validate_database_exists
+#'
+#' @description
+#' Checks whether a database with the specified name exists on the current connection.
+#'
+#' @details
+#' This function queries the available databases for the connection using
+#' `motherduck::list_all_databases()` and performs an exact match check.
+#' Returns `TRUE` if the database exists, `FALSE` otherwise.
+#'
+#' @param .con A valid `DBI` connection (DuckDB / MotherDuck).
+#' @param database_name A string specifying the database name to check.
+#'
+#' @return
+#' Logical `TRUE` if the database exists, `FALSE` otherwise.
+#' @examples
+#' \dontrun{
+#' con <- DBI::dbConnect(duckdb::duckdb())
+#' validate_database_exists(con, "test_db")
+#' }
+#'
+#' @export
+validate_database_exists <- function(.con,database_name){
+  
+ 
+  
+  db_vec <-  show_information_schema(.con) |>
+    dplyr::pull(catalog_name) 
+  
+  
+  if(any(database_name %in% db_vec)){
+    
+    return(TRUE)
+    
+  }
+  
+  return(FALSE)
+  
+  
+}
 
 
+#' @title Check if a Schema Exists in a Database
+#' @name validate_database_schema_exists
+#'
+#' @description
+#' Checks whether a schema with the specified name exists within a given database.
+#'
+#' @details
+#' This function queries all tables in the connection using
+#' `motherduck::list_all_tables()`, filters by `table_catalog` (database),
+#' and performs an exact match on the schema name.
+#'
+#' @param .con A valid `DBI` connection (DuckDB / MotherDuck).
+#' @param database_name The database name to check.
+#' @param schema_name The schema name to check within the database.
+#'
+#' @return
+#' Logical `TRUE` if the schema exists, `FALSE` otherwise.
+#'
+#' @examples
+#' \dontrun{
+#' con <- DBI::dbConnect(duckdb::duckdb())
+#' validate_database_schema_exists(con, "test_db", "main")
+#' }
+#'
+#' @export
+validate_database_schema_exists <- function(.con,database_name,schema_name){
+  
+  
+  db_vec <-  show_information_schema(.con) |> 
+    dplyr::filter(catalog_name %in% database_name) |> 
+    dplyr::pull(schema_name) 
+  
+  
+  if(any(schema_name %in% db_vec)){
+    
+    return(TRUE)
+    
+  }
+  
+  return(FALSE)
+  
+}
+
+
+
+
+#' Show Information Schema Schemas
+#'
+#' @description
+#' List all schemas available in the connected database.
+#'
+#' This function queries the `information_schema.schemata` view to return
+#' metadata about schemas that exist in the database associated with the
+#' provided DBI connection. It is intended for inspection and debugging
+#' purposes and does not modify database state.
+#'
+#' @inheritParams validate_con
+#' @returns A tibble with one row per schema. Columns typically include
+#'   catalog name, schema name, schema owner, and other database-specific
+#'   metadata as defined by the SQL information schema.
+#'
+#' @details
+#' The structure and contents of the returned tibble depend on the database
+#' backend. Databases may expose additional or fewer columns in
+#' `information_schema.schemata`.
+#'
+#' @export
+#'
+#' @examples
+#' \dontrun{
+#' library(DBI)
+#' con <- dbConnect(duckdb::duckdb())
+#'
+#' show_information_schema(con)
+#'
+#' dbDisconnect(con, shutdown = TRUE)
+#' }
+show_information_schema <- function(.con){
+  
+  
+  validate_con(.con)
+  
+  out <- DBI::dbGetQuery(
+    .con
+    ,dplyr::sql("
+    SELECT *
+    FROM information_schema.schemata
+              ")
+  ) |> 
+    tibble::as_tibble()
+  
+  return(out)
+  
+  
+}
 
 utils::globalVariables(
-  c("table_catalog", "table_schema", "table_name","current_database")
+  c("table_catalog", "table_schema", "table_name","current_database","db_vec")
 )
 
 
